@@ -10,6 +10,26 @@ class EmptySerializer(serializers.Serializer):
 
 
 class CashTokenSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = Token
+        fields = (
+            'category',
+            'name',
+            'symbol',
+            'description',
+            'decimals',
+            'icon',
+            'status',
+            'date_created',
+            'owner',
+        )
+        read_only_fields = (
+            'date_created',
+            'owner',
+        )
+
+
+class RegistryIdentitySerializer(serializers.ModelSerializer):
     time = serializers.SerializerMethodField()
     token = serializers.SerializerMethodField()
     uris = serializers.SerializerMethodField()
@@ -49,9 +69,29 @@ class RegistrySerializer(serializers.ModelSerializer):
     class Meta:
         model = Registry
         fields = (
+            'id',
             'name',
             'description',
             'tokens',
+            'owner',
+        )
+        read_only_fields = (
+            'owner',
+            'id',
+        )
+
+
+class NoOwnerRegistrySerializer(serializers.ModelSerializer):
+    class Meta:
+        model = Registry
+        fields = (
+            'id',
+            'name',
+            'description',
+            'tokens',
+        )
+        read_only_fields = (
+            'id',
         )
 
 
@@ -94,7 +134,7 @@ class BcmrRegistrySerializer(serializers.ModelSerializer):
         identities = {}
 
         for token in tokens:
-            t = CashTokenSerializer(token).data
+            t = RegistryIdentitySerializer(token).data
             identities[t['token']['category']] = [t]
 
         return identities
